@@ -177,15 +177,24 @@ class SchemaNode:
         self.array_items = array_items or []
         self.refers_to = refers_to
         self.is_displayed = is_displayed
+        self._refers_to_merged = None
 
     @property
     def definition_name(self) -> str:
-        if self.ref_path:
-            return self.ref_path.split("/")[-1]
+        """The text to display when this node is the title of a section or tab"""
+        if self.is_property and self.parent_key:
+            return self.parent_key
         if self.title:
             return self.title
+        if self.ref_path:
+            return self.ref_path.split("/")[-1]
         return ""
 
+    @property
+    def link_name(self) -> str:
+        """The text to display when linking to this node from somewhere else in the schema"""
+        return self.definition_name or self.html_id
+
     @property
     def is_property(self) -> bool:
         return bool(self.parent and self.parent.parent_key == KW_PROPERTIES)
@@ -264,6 +273,21 @@ class SchemaNode:
 
         return possible_examples
 
+    @property
+    def refers_to_merged(self) -> Optional["SchemaNode"]:
+        """The referenced node, with values from the current node merged in"""
+        if self._refers_to_merged:
+            return self._refers_to_merged
+
+        if not self.refers_to:
+            return None
+
+        merged_node = copy.deepcopy(self.refers_to)
+        merged_node.keywords.update(self.keywords)
+        self._refers_to_merged = merged_node
+
+        return self._refers_to_merged
+
     def get_keyword(self, keyword: str) -> Optional["SchemaNode"]:
         """Get the value of a keyword if present and it is not a property (to avoid conflicts with properties being
         named like a keyword, e.g. a property named "if")
