@@ -27,7 +27,7 @@ def test_recursive_array() -> None:
 
     recursive_definition_link = soup.find("a", href="#person_items")
     assert recursive_definition_link
-    assert recursive_definition_link.text == "Same definition as person_items"
+    assert recursive_definition_link.text == "Same definition as person"
 
 
 @pytest.mark.parametrize("link_to_reused_ref", [True, False])
@@ -48,6 +48,6 @@ def test_recursive_two_files(link_to_reused_ref: bool) -> None:
     recursive_definition_link = soup.find("a", href="#person_siblings")
     if link_to_reused_ref:
         assert recursive_definition_link
-        assert recursive_definition_link.text == "Same definition as person_siblings"
+        assert recursive_definition_link.text == "Same definition as siblings"
     else:
         assert not recursive_definition_link
